@@ -172,12 +172,11 @@ class FileHelper:
     def write_sql(self, table_name: str, df: pd.DataFrame, table_schema: Schema = None, if_exists="replace", index=False, **kwargs):
         engine = self.get_engine()
         result = df.to_sql(table_name, engine, if_exists=if_exists, index=index, **kwargs)
-        print("Wrote to table", table_name, "- result:", result)
+        self.logger.success(f"Wrote to table {table_name} - result: {result}")
 
     # Read schema from disk
     def read_schema(self, path: str):
         schema_dict = json.loads(self.read_text(f"schemas/{path}.json"))
-        print(schema_dict)
         return Schema(schema_dict)
 
     # Read schema from default location for a SQL table
